Static translations - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Static translations

Type | `betty.locale.localizable.config.StaticTranslationsLocalizableConfiguration`

## All configuration options

This configuration is either a single translation as a string, or multiple translations as a key-value mapping.

### A single translation

Type | string

A single translation can be set that is to be used for all languages.

Example configuration:

YAML

    "I am a single translation, used for all languages"

JSON

    "I am a single translation, used for all languages"

### Multiple translations

Type | mapping Keys (string) are IETF BCP 47 language tags, and values (string) are human-readable translations.

Example configuration:

YAML

    en-US: "I'm the English translation"
    nl-NL: "Ik ben de Nederlandse vertaling"

JSON

    {
      "en-US": "I'm the English translation",
      "nl-NL": "Ik ben de Nederlandse vertaling",
    }